@@ -1,7 +1,4 @@
 package DNS::Oterica::NodeFamily::ExampleDomain;
-our $VERSION = '0.092950';
-
-
 use Moose;
 extends 'DNS::Oterica::NodeFamily';
 
@@ -11,7 +8,7 @@ augment as_data_lines => sub {
   my ($self) = @_;
   my @lines;
 
-  my %ns_nodes = $self->hub->node_family('com.example.ns')->ns_nodes;
+  my $ns_nodes = $self->hub->node_family('com.example.ns')->ns_nodes;
 
   for my $node ($self->nodes) {
     push @lines, $self->rec->soa_and_ns({
@@ -19,7 +16,7 @@ augment as_data_lines => sub {
       ns     => 'ns.example.com',
       node   => $node,
     });
-    for my $ns (keys %ns_nodes) {
+    for my $ns (keys %$ns_nodes) {
       push @lines, $self->rec->domain({
         domain => $node->fqdn,
         ns     => $ns,
