@@ -1,7 +1,4 @@
 package DNS::Oterica::NodeFamily::ExampleMX;
-our $VERSION = '0.092950';
-
-
 use Moose;
 extends 'DNS::Oterica::NodeFamily';
 
@@ -11,7 +8,6 @@ has mx_nodes => (
   is  => 'ro',
   isa => 'HashRef',
   default    => sub { {} },
-  auto_deref => 1,
 );
 
 after add_node => sub {
@@ -28,11 +24,11 @@ augment as_data_lines => sub {
   my ($self) = @_;
   my @lines;
 
-  my %mx = $self->mx_nodes;
-  for my $mxname (sort keys %mx) {
+  my $mx = $self->mx_nodes;
+  for my $mxname (sort keys %$mx) {
     push @lines, $self->rec->a({
       name => $mxname,
-      node => $mx{$mxname},
+      node => $mx->{$mxname},
     });
   }
   return @lines;
