@@ -1,7 +1,4 @@
 package DNS::Oterica::NodeFamily::ExampleNS;
-our $VERSION = '0.092950';
-
-
 use Moose;
 extends 'DNS::Oterica::NodeFamily';
 
@@ -11,7 +8,6 @@ has ns_nodes => (
   is  => 'ro',
   isa => 'HashRef',
   default    => sub { {} },
-  auto_deref => 1,
 );
 
 after add_node => sub {
@@ -28,15 +24,15 @@ augment as_data_lines => sub {
   my ($self) = @_;
   my @lines;
 
-  my %ns = $self->ns_nodes;
-  for my $name (sort keys %ns) {
+  my $ns = $self->ns_nodes;
+  for my $name (sort keys %$ns) {
     push @lines, $self->rec->a({
       name => $name,
-      node => $ns{$name},
+      node => $ns->{$name},
     });
     push @lines, $self->rec->a({
       name => 'mydns.ns.example.com',
-      node => $ns{$name},
+      node => $ns->{$name},
     });
   }
 
